@@ -17,6 +17,12 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
+#ifdef __cplusplus
+/* *INDENT-OFF* */
+extern "C" {
+/* *INDENT-ON* */
+#endif
+
 struct {
 	char	*name;
 	char	*desc;
@@ -35,3 +41,10 @@ struct {
 	{ "BYPASS",	"BYPASS",		2	},
 	{ NULL,		NULL,			0	}
 };
+
+#ifdef __cplusplus
+/* *INDENT-OFF* */
+}
+/* *INDENT-ON* */
+#endif
+
