@@ -26,9 +26,7 @@
 #ifndef BELKIN_HID_H
 #define BELKIN_HID_H
 
-#include "newhidups.h"
-
-#define BELKIN_HID_VERSION	"Belkin HID 0.1"
+#include "usbhid-ups.h"
 
 extern subdriver_t belkin_subdriver;
 
