@@ -1,6 +1,8 @@
 /* dstate.h - Network UPS Tools driver-side state management
 
-   Copyright (C) 2003  Russell Kroll <rkroll@exploits.org>
+   Copyright (C)
+	2003	Russell Kroll <rkroll@exploits.org>
+	2012	Arnaud Quette <arnaud.quette@free.fr>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -45,12 +47,14 @@ int dstate_setinfo(const char *var, const char *fmt, ...)
 	__attribute__ ((__format__ (__printf__, 2, 3)));
 int dstate_addenum(const char *var, const char *fmt, ...)
 	__attribute__ ((__format__ (__printf__, 2, 3)));
+int dstate_addrange(const char *var, const int min, const int max);
 void dstate_setflags(const char *var, int flags);
 void dstate_setaux(const char *var, int aux);
 const char *dstate_getinfo(const char *var);
 void dstate_addcmd(const char *cmdname);
 int dstate_delinfo(const char *var);
 int dstate_delenum(const char *var, const char *val);
+int dstate_delrange(const char *var, const int min, const int max);
 int dstate_delcmd(const char *cmd);
 void dstate_free(void);
 const st_tree_t *dstate_getroot(void);
