@@ -33,9 +33,6 @@
 #include "usb-common.h"
 #include "libusb.h"
 
-/* USB standard timeout */
-#define USB_TIMEOUT 5000
-
 #define USB_DRIVER_NAME		"USB communication driver"
 #define USB_DRIVER_VERSION	"0.32"
 
@@ -375,7 +372,9 @@ static int libusb_strerror(const int ret, const char *desc)
 		return 0;
 
 	case -EOVERFLOW:	/* Value too large for defined data type */
+#ifdef EPROTO
 	case -EPROTO:	/* Protocol error */
+#endif
 		upsdebugx(2, "%s: %s", desc, usb_strerror());
 		return 0;
 
