@@ -3,7 +3,7 @@
  *  Based on NetSNMP API (Simple Network Management Protocol V1-2)
  *
  *  Copyright (C)
- *	2002 - 2012	Arnaud Quette <arnaud.quette@free.fr>
+ *	2002 - 2014	Arnaud Quette <arnaud.quette@free.fr>
  *	2002 - 2006	Dmitry Frolov <frolov@riss-telecom.ru>
  *			J.W. Hoogervorst <jeroen@hoogervorst.net>
  *			Niels Baggesen <niels@baggesen.net>
@@ -49,6 +49,7 @@
 #include "cyberpower-mib.h"
 #include "delta_ups-mib.h"
 #include "ietf-mib.h"
+#include "xppc-mib.h"
 
 /* Address API change */
 #ifndef usmAESPrivProtocol
@@ -71,6 +72,7 @@ static mib2nut_info_t *mib2nut[] = {
 	&bestpower,
 	&cyberpower,
 	&delta_ups,
+        &xppc,
 	/*
 	 * Prepend vendor specific MIB mappings before IETF, so that
 	 * if a device supports both IETF and vendor specific MIB,
@@ -98,7 +100,7 @@ const char *mibvers;
 static void disable_transfer_oids(void);
 
 #define DRIVER_NAME	"Generic SNMP UPS driver"
-#define DRIVER_VERSION		"0.70"
+#define DRIVER_VERSION		"0.72"
 
 /* driver description structure */
 upsdrv_info_t	upsdrv_info = {
@@ -586,6 +588,9 @@ struct snmp_pdu *nut_snmp_get(const char *OID)
 	struct snmp_pdu ** pdu_array;
 	struct snmp_pdu * ret_pdu;
 
+	if (OID == NULL)
+		return NULL;
+
 	upsdebugx(3, "nut_snmp_get(%s)", OID);
 
 	pdu_array = nut_snmp_walk(OID,1);
