@@ -3,6 +3,7 @@
    Copyright (C)
 	2003	Russell Kroll <rkroll@exploits.org>
 	2008	Arjen de Korte <adkorte-guest@alioth.debian.org>
+	2012	Arnaud Quette <arnaud.quette@free.fr>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -63,6 +64,7 @@ static int parse_args(upstype_t *ups, int numargs, char **arg)
 	if (numargs < 2)
 		return 0;
 
+	/* FIXME: all these should return their state_...() value! */
 	/* ADDCMD <cmdname> */
 	if (!strcasecmp(arg[0], "ADDCMD")) {
 		state_addcmd(&ups->cmdlist, arg[1]);
@@ -88,7 +90,7 @@ static int parse_args(upstype_t *ups, int numargs, char **arg)
 	if (!strcasecmp(arg[0], "SETFLAGS")) {
 		state_setflags(ups->inforoot, arg[1], numargs - 2, &arg[2]);
 		return 1;
-	}		
+	}
 
 	/* SETINFO <varname> <value> */
 	if (!strcasecmp(arg[0], "SETINFO")) {
@@ -102,12 +104,24 @@ static int parse_args(upstype_t *ups, int numargs, char **arg)
 		return 1;
 	}
 
+	/* ADDRANGE <varname> <minvalue> <maxvalue> */
+	if (!strcasecmp(arg[0], "ADDRANGE")) {
+		state_addrange(ups->inforoot, arg[1], atoi(arg[2]), atoi(arg[3]));
+		return 1;
+	}
+
 	/* DELENUM <varname> <enumval> */
 	if (!strcasecmp(arg[0], "DELENUM")) {
 		state_delenum(ups->inforoot, arg[1], arg[2]);
 		return 1;
 	}
 
+	/* DELRANGE <varname> <minvalue> <maxvalue> */
+	if (!strcasecmp(arg[0], "DELRANGE")) {
+		state_delrange(ups->inforoot, arg[1], atoi(arg[2]), atoi(arg[3]));
+		return 1;
+	}
+
 	/* SETAUX <varname> <auxval> */
 	if (!strcasecmp(arg[0], "SETAUX")) {
 		state_setaux(ups->inforoot, arg[1], arg[2]);
@@ -301,6 +315,11 @@ const enum_t *sstate_getenumlist(const upstype_t *ups, const char *var)
 	return state_getenumlist(ups->inforoot, var);
 }
 
+const range_t *sstate_getrangelist(const upstype_t *ups, const char *var)
+{
+	return state_getrangelist(ups->inforoot, var);
+}
+
 const cmdlist_t *sstate_getcmdlist(const upstype_t *ups)
 {
 	return ups->cmdlist;
