@@ -31,7 +31,7 @@ typedef struct {
 /* USB IDs device table */
 static usb_device_id_t usb_device_table[] = {
 
-	{ 0x0001, 0x0000, "blazer_usb" },
+	{ 0x0001, 0x0000, "nutdrv_atcl_usb" },
 	{ 0x03f0, 0x0001, "usbhid-ups" },
 	{ 0x03f0, 0x1f01, "bcmxcp_usb" },
 	{ 0x03f0, 0x1f02, "bcmxcp_usb" },
@@ -119,6 +119,7 @@ static usb_device_id_t usb_device_table[] = {
 	{ 0x0d9f, 0x00a6, "usbhid-ups" },
 	{ 0x0f03, 0x0001, "blazer_usb" },
 	{ 0x10af, 0x0001, "usbhid-ups" },
+	{ 0x10af, 0x0004, "usbhid-ups" },
 	{ 0x14f0, 0x00c9, "blazer_usb" },
 	{ 0xffff, 0x0000, "blazer_usb" },
 	/* Terminating entry */
